@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ use Log::Any::IfLOG '$log';
 use Data::Dmp;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(gen_perinci_cmdline_completer_script);
+our @EXPORT_OK = qw(gen_pericmd_completer_script);
 
 our %SPEC;
 
@@ -33,7 +33,7 @@ sub _riap_request {
     _pa()->request($action => $url, %{$extras // {}});
 }
 
-$SPEC{gen_perinci_cmdline_completer_script} = {
+$SPEC{gen_pericmd_completer_script} = {
     v => 1.1,
     summary => 'Generate Perinci::CmdLine completer script',
     args => {
@@ -50,20 +50,20 @@ $SPEC{gen_perinci_cmdline_completer_script} = {
             pos => 1,
             tags => ['category:pericmd-attribute'],
         },
-        subcommand => {
-            summary => 'Subcommand name followed by colon and function URL',
+        subcommands => {
+            summary => 'Hash of subcommand names and function URLs',
             description => <<'_',
 
 Optionally, it can be additionally followed by a summary, so:
 
-    NAME:URL[:SUMMARY]
+    URL[:SUMMARY]
 
 Example (on CLI):
 
-    --subcommand "delete:/My/App/delete_item:Delete an item"
+    --subcommand "delete=/My/App/delete_item:Delete an item"
 
 _
-            schema => ['array*', of=>'str*'],
+            schema => ['hash*', of=>['any*', of=>['hash*', 'str*']]],
             cmdline_aliases => { s=>{} },
             tags => ['category:pericmd-attribute'],
         },
@@ -161,7 +161,7 @@ _
         },
     },
 };
-sub gen_perinci_cmdline_completer_script {
+sub gen_pericmd_completer_script {
     require Perinci::CmdLine::Lite;
 
     my %args = @_;
@@ -171,10 +171,17 @@ sub gen_perinci_cmdline_completer_script {
 
     my $subcommands;
     my $sc_metas = {};
-    if ($args{subcommand} && @{ $args{subcommand} }) {
+    if ($args{subcommands}) {
         $subcommands = {};
-        for (@{ $args{subcommand} }) {
-            my ($sc_name, $sc_url, $sc_summary) = split /:/, $_, 3;
+        for my $sc_name (keys %{ $args{subcommands} }) {
+            my $v = $args{subcommands}{$sc_name};
+            my ($sc_url, $sc_summary);
+            if (ref($v) eq 'HASH') {
+                $sc_url = $v->{url};
+                $sc_summary = $v->{summary};
+            } else {
+                ($sc_url, $sc_summary) = split /:/, $v, 2;
+            }
             my $res = _riap_request(meta => $sc_url => {}, \%args);
             return [500, "Can't meta $sc_url: $res->[0] - $res->[1]"]
                 unless $res->[0] == 200;
@@ -221,7 +228,7 @@ sub gen_perinci_cmdline_completer_script {
     my $cli;
     {
         use experimental 'smartmatch';
-        my $spec = $SPEC{gen_perinci_cmdline_completer_script};
+        my $spec = $SPEC{gen_pericmd_completer_script};
         my @attr_args = grep {
             'category:pericmd-attribute' ~~ @{ $spec->{args}{$_}{tags} } }
             keys %{ $spec->{args} };
@@ -449,12 +456,12 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.09 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2016-12-02.
+This document describes version 0.10 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2017-01-12.
 
 =head1 FUNCTIONS
 
 
-=head2 gen_perinci_cmdline_completer_script(%args) -> [status, msg, result, meta]
+=head2 gen_pericmd_completer_script(%args) -> [status, msg, result, meta]
 
 Generate Perinci::CmdLine completer script.
 
@@ -508,17 +515,17 @@ Program name that is being completed.
 
 =item * B<skip_format> => I<bool>
 
-=item * B<subcommand> => I<array[str]>
+=item * B<subcommands> => I<hash>
 
-Subcommand name followed by colon and function URL.
+Hash of subcommand names and function URLs.
 
 Optionally, it can be additionally followed by a summary, so:
 
- NAME:URL[:SUMMARY]
+ URL[:SUMMARY]
 
 Example (on CLI):
 
- --subcommand "delete:/My/App/delete_item:Delete an item"
+ --subcommand "delete=/My/App/delete_item:Delete an item"
 
 =item * B<subcommands_from_package_functions> => I<bool>
 
@@ -578,7 +585,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
